@@ -1,5 +1,5 @@
 from ._main import wlsplit,wltopk
-from ..searchlite import web
+from ...searchlite import web
 def web_wordllama(query: str, k: int = 1, wk: int = 1, return_chunks=False):
     __chunks = wlsplit(web(query, k=wk))
     answer_chunks = wltopk(__chunks, query, k=k)
